package com.shzg.project.worn.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.shzg.framework.aspectj.lang.annotation.Log;
import com.shzg.framework.aspectj.lang.enums.BusinessType;
import com.shzg.project.worn.domain.WornMaterialType;
import com.shzg.project.worn.service.IWornMaterialTypeService;
import com.shzg.framework.web.controller.BaseController;
import com.shzg.framework.web.domain.AjaxResult;
import com.shzg.common.utils.poi.ExcelUtil;
import com.shzg.framework.web.page.TableDataInfo;

/**
 * 物料类型Controller
 * 
 * @author shzg
 * @date 2026-03-11
 */
@RestController
@RequestMapping("/worn/type")
public class WornMaterialTypeController extends BaseController
{
    @Autowired
    private IWornMaterialTypeService wornMaterialTypeService;

    /**
     * 查询物料类型列表
     */
    @PreAuthorize("@ss.hasPermi('worn:type:list')")
    @GetMapping("/list")
    public TableDataInfo list(WornMaterialType wornMaterialType)
    {
        startPage();
        List<WornMaterialType> list = wornMaterialTypeService.selectWornMaterialTypeList(wornMaterialType);
        return getDataTable(list);
    }


    /**
     * 导出物料类型列表
     */
    @PreAuthorize("@ss.hasPermi('worn:type:export')")
    @Log(title = "物料类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WornMaterialType wornMaterialType)
    {
        List<WornMaterialType> list = wornMaterialTypeService.selectWornMaterialTypeList(wornMaterialType);
        ExcelUtil<WornMaterialType> util = new ExcelUtil<WornMaterialType>(WornMaterialType.class);
        util.exportExcel(response, list, "物料类型数据");
    }

    /**
     * 获取物料类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('worn:type:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wornMaterialTypeService.selectWornMaterialTypeById(id));
    }

    /**
     * 新增物料类型
     */
    @PreAuthorize("@ss.hasPermi('worn:type:add')")
    @Log(title = "物料类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WornMaterialType wornMaterialType)
    {
        return toAjax(wornMaterialTypeService.insertWornMaterialType(wornMaterialType));
    }

    /**
     * 修改物料类型
     */
    @PreAuthorize("@ss.hasPermi('worn:type:edit')")
    @Log(title = "物料类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WornMaterialType wornMaterialType)
    {
        return toAjax(wornMaterialTypeService.updateWornMaterialType(wornMaterialType));
    }

    /**
     * 删除物料类型
     */
    @PreAuthorize("@ss.hasPermi('worn:type:remove')")
    @Log(title = "物料类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wornMaterialTypeService.deleteWornMaterialTypeByIds(ids));
    }

    /**
     * 查询物料类型树结构
     */
    @PreAuthorize("@ss.hasPermi('worn:type:list')")
    @GetMapping("/tree")
    public AjaxResult tree()
    {
        List<WornMaterialType> tree = wornMaterialTypeService.selectWornMaterialTypeTree();
        return AjaxResult.success(tree);
    }

}
